@@ -15,11 +15,8 @@ module TDiary
 		end
 
 		def save
-			result = ERB.new(File.read("#{File.dirname(__FILE__)}/../../views/tdiary.rconf").untaint).result(binding)
-			result.untaint
-			Safe::safe do
-				eval( result, binding, "(TDiary::Configuration#save)", 1 )
-			end
+			result = ERB.new(File.read("#{File.dirname(__FILE__)}/../../views/tdiary.rconf")).result(binding)
+			eval( result, binding, "(TDiary::Configuration#save)", 1 )
 			@io_class.save_cgi_conf(self, result)
 		end
 
@@ -113,23 +110,20 @@ module TDiary
 			end
 
 			cgi_conf = @io_class.load_cgi_conf(self)
-			cgi_conf.untaint
 
-			b = binding.taint
+			b = binding
 			eval( def_vars1, b )
-			Safe::safe do
-				begin
-					eval( cgi_conf, b, "(TDiary::Configuration#load_cgi_conf)", 1 )
-				rescue SyntaxError
-					enc = case @lang
-							when 'en'
-								'UTF-8'
-							else
-								'EUC-JP'
-							end
-					cgi_conf.force_encoding( enc )
-					retry
-				end
+			begin
+				eval( cgi_conf, b, "(TDiary::Configuration#load_cgi_conf)", 1 )
+			rescue SyntaxError
+				enc = case @lang
+						when 'en'
+							'UTF-8'
+						else
+							'EUC-JP'
+						end
+				cgi_conf.force_encoding( enc )
+				retry
 			end if cgi_conf
 			eval( def_vars2, b )
 		end
@@ -138,12 +132,12 @@ module TDiary
 		def configure_attrs
 			@options = {}
 
-			eval( File::open( 'tdiary.conf' ) {|f| f.read }.untaint, nil, "(tdiary.conf)", 1 )
+			eval( File::open( 'tdiary.conf' ) {|f| f.read }, nil, "(tdiary.conf)", 1 )
 
 			# language setup
 			@lang = 'ja' unless @lang
 			begin
-				instance_eval( File::open( "#{TDiary::PATH}/tdiary/lang/#{@lang}.rb" ){|f| f.read }.untaint, "(tdiary/lang/#{@lang}.rb)", 1 )
+				instance_eval( File::open( "#{TDiary::PATH}/tdiary/lang/#{@lang}.rb" ){|f| f.read }, "(tdiary/lang/#{@lang}.rb)", 1 )
 			rescue Errno::ENOENT
 				@lang = 'ja'
 				retry
@@ -195,9 +189,8 @@ module TDiary
 			if @options2 then
 				@options.update( @options2 )
 			else
-				@options2 = {}.taint
+				@options2 = {}
 			end
-			@options.taint
 
 			# for 1.4 compatibility
 			@section_anchor = @paragraph_anchor unless @section_anchor
@@ -220,7 +213,7 @@ module TDiary
 			else
 				require 'logger'
 				log_path = (@log_path || "#{@data_path}/log")
-				FileUtils.mkdir_p(log_path.untaint)
+				FileUtils.mkdir_p(log_path)
 				TDiary.logger = Logger.new(File.join(log_path, "debug.log"), 'daily')
 				TDiary.logger.level = Logger.const_get(@log_level || 'DEBUG')
 			end
