@@ -1,4 +1,4 @@
-$:.unshift File.expand_path(File.join(File.dirname(__FILE__), '../../misc/plugin')).untaint
+$:.unshift File.expand_path(File.join(File.dirname(__FILE__), '../../misc/plugin'))
 
 require File.dirname(__FILE__) + "/../spec_helper"
 require 'erb'
